==> spip_4.0.4.orig.tar.xz: plugins-dist/forum/lang/forum_fon.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=fon
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'Wekpa é jà wé lɛ̂ kɛɖɛ ( yé mà ɖalɔ xoklpé wu o)',
	'bouton_radio_articles_tous' => 'Xogbè lɛ̂bi',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'Xogbè lɛ̂ bi, yé jo Xogbè é agun yé mà jɛ a ɖo',
	'bouton_radio_enregistrement_obligatoire' => 'wiwlihɛn ɖo tàji ( mɛ nɔ zan nu lɛ ɔ ɖo na e-mailu yé jo co yé na sɛ alɔdo yé tɔn do',
	'bouton_radio_moderation_priori' => 'dɛdɛ vlɛ ( nu yé ma sɔ kɛn nu alɔdo mi tɔn a mi siwu ze yé xlɛ a )', # MODIF
	'bouton_radio_modere_abonnement' => 'mi dalɔ nyikɔzinzin wu ',
	'bouton_radio_modere_posteriori' => 'mi dalɔ wu ', # MODIF
	'bouton_radio_modere_priori' => 'mi dalɔ wu ', # MODIF
	'bouton_radio_publication_immediate' => 'Mi na ɖé wɛn xlɛ azɔn ɖokpo, sisɛɖo kpoɖo ɖiɖèxlɛ alɔdo, gânl lɛ̂ hɛn ɔ yé siwu sunsun yé ',

	// F
	'form_pet_message_commentaire' => 'wɛn, tɛ xójí?',
	'forum' => 'Kplékplé ',
	'forum_acces_refuse' => 'Mì sɔ síwú byɔ Kpékpé ɔ mɛ á.',
	'forum_attention_dix_caracteres' => 'vlɛ ! wékwín é wlán wɛn mí tɔn é sù wó á.', # MODIF
	'forum_attention_trois_caracteres' => 'vlɛ ! wékwín é wlán xóta mí tɔn é kpé àtɔn á.', # MODIF
	'forum_avez_selectionne' => 'mì cían:',
	'forum_cliquer_retour' => 'Mì zín @lɛkɔkplékplé@ mì yì',
	'forum_forum' => 'kpléklpé',
	'forum_info_modere' => 'Kpléklpé é lɔ ɖó jlɛɖɔtɔ, nú yé sɔ kɛn nú xògbè mì tɔn fó ɔ, é ná tɔn tà .', # MODIF
	'forum_lien_hyper' => 'cácádó', # MODIF
	'forum_message_definitif' => 'wɛn gùɖógùɖó tɔn, sɛɖó gblogblo ɔ jí',
	'forum_message_trop_long' => 'wɛn mì tɔn ɖìga ɖín. kpìnkpɛn tɔn ɖó ná zɛ wěkwin càkìkò wú á ', # MODIF
	'forum_ne_repondez_pas' => 'mì mà yígbè nú e-mailù é lɔ ó, àmɔ ɖò kplékplé ɔ mɛ ɔ mì kpɔn nɔtɛn é lɔ ', # MODIF
	'forum_page_url' => '(nú é nyí  ɖɔ wɛn mì tɔn tɛɖó wékpá é xlɛ ɖò àtɛ ɔ jí ɔ, kàbí wěmá é nɔ xlɛ xó gege ɔ, mì sìwú ɖè xótá àló nɔtɛn wěkpá tɔn ɖò fí.)',
	'forum_poste_par' => '@nyɔwlántɔ ɖókpóɖókpó sɛ wɛn ɖó@gbètákɛnxòkplé ɔ gbàfɔ, yè sìwú wlí wɛn mì tɔn hɛn á', # MODIF
	'forum_qui_etes_vous' => 'mɛcé ká ɖyè', # MODIF
	'forum_texte' => 'xó é ɖò wɛn ɔ mɛ ɔ :', # MODIF
	'forum_titre' => 'xótá :', # MODIF
	'forum_url' => 'URLU:', # MODIF
	'forum_valider' => 'sɔ kɛŋ ná  nù è mì cyán é',
	'forum_voir_avant' => 'mí kpɔn wɛn é lɔ có bó sɛɖó', # MODIF
	'forum_votre_email' => 'e-mailù mi tɔn  :', # MODIF
	'forum_votre_nom' => 'nyìkɔ mi tɔn :', # MODIF
	'forum_vous_enregistrer' => 'nú mi ná ɖó byɔ kplékplé é lɔ mɛ ɔ, mi ɖó ná ná nyìkɔ tɔn hwɛ. Mi zé sùnyíkɔ mi tɔn zé xlɛ. Nú mi mà kò nyìkɔ á, mi ɖó ná',
	'forum_vous_inscrire' => 'mi ɖó ná ná nyìkɔ .',

	// I
	'icone_poster_message' => 'sɛ wɛn dó',
	'icone_suivi_forum' => 'nɔkɔn xwíxwlété àgùn ɔ tɔn ',
	'icone_suivi_forums' => 'cɔ/tìtò klpékplé ɔ tɔn ',
	'icone_supprimer_message' => 'gbìɖí wɛn é lɔ',
	'icone_valider_message' => 'sɔ kɛn nú wɛn é lɔ',
	'info_activer_forum_public' => 'nú mi ná zɔn bɔ axì ná jɛ ɖò àgun ɔ mɛ ɔ ', # MODIF
	'info_appliquer_choix_moderation' => 'mi zán wàlɔ é lɔ ɖɛɖɛ:',
	'info_desactiver_forum_public' => 'kplékplénɔ lɛ ní jó xó dó',
	'info_envoi_forum' => 'mi sɛ wɛn àgún mɛ tɔn lɛ ɖó nyɔnwlántɔ lɛ ',
	'info_fonctionnement_forum' => 'Kplékplé ɔ sín yíyí:',
	'info_gauche_suivi_forum_2' => 'wémà é lɔ Tìtòtɔ lɛ kɛɖɛ wɛ síwú dàlɔmɛ', # MODIF
	'info_liens_syndiques_3' => 'kplékplé lɛ',
	'info_liens_syndiques_4' => 'Yé ɖò',
	'info_liens_syndiques_5' => 'kplékplé',
	'info_liens_syndiques_6' => 'E ɖò',
	'info_liens_syndiques_7' => 'yé bónú yé ní sɔ kɛn ná',
	'info_mode_fonctionnement_defaut_forum_public' => 'àzɔ yiyi wɛ',
	'info_option_email' => 'Mi yí gbè nú jònɔ é ná nyíkɔ lɛ ', # MODIF
	'info_pas_de_forum' => 'kplékplé mà tín',
	'item_activer_forum_administrateur' => 'tìtòtɔ lɛ sín kplékplé ní jɛ àzɔ wà jí',
	'item_desactiver_forum_administrateur' => 'Tìtótɔ lɛ',

	// L
	'lien_reponse_article' => 'yígbjè nú wékpá é lɔ',
	'lien_reponse_breve_2' => 'yígbjè nú xó kléwún é lɔ',
	'lien_reponse_rubrique' => 'yígbjè nú àkpáxwé  é lɔ',
	'lien_reponse_site_reference' => 'yígbjè nú gblogblojí ɔ  é lɔ :', # MODIF

	// O
	'onglet_messages_internes' => 'wɛn dódó',
	'onglet_messages_publics' => 'wɛn tò bí tùn ',
	'onglet_messages_vide' => 'wɛn mà ɖò wě',

	// R
	'repondre_message' => 'ɖò sin nu wɛn  é lɔ',

	// T
	'titre_cadre_forum_administrateur' => 'tìtòtɔ lɛ síŋ kplékplé',
	'titre_cadre_forum_interne' => 'kplékplé',
	'titre_forum' => 'kplékplé',
	'titre_forum_suivi' => 'Bɔ núkún nú kplékplé ɔ',
	'titre_page_forum_suivi' => 'Bɔnúkún kplékplé ɔ jí'
);

==> spip_4.2.12+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_fon.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=fon
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'Wekpa é jà wé lɛ̂ kɛɖɛ ( yé mà ɖalɔ xoklpé wu o)',
	'bouton_radio_articles_tous' => 'Xogbè lɛ̂bi',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'Xogbè lɛ̂ bi, yé jo Xogbè é agun yé mà jɛ a ɖo',
	'bouton_radio_enregistrement_obligatoire' => 'wiwlihɛn ɖo tàji ( mɛ nɔ zan nu lɛ ɔ ɖo na e-mailu yé jo co yé na sɛ alɔdo yé tɔn do',
	'bouton_radio_moderation_priori' => 'dɛdɛ vlɛ ( nu yé ma sɔ kɛn nu alɔdo mi tɔn a mi siwu ze yé xlɛ a )', # MODIF
	'bouton_radio_modere_abonnement' => 'mi dalɔ nyikɔzinzin wu ',
	'bouton_radio_modere_posteriori' => 'mi dalɔ wu ', # MODIF
	'bouton_radio_modere_priori' => 'mi dalɔ wu ', # MODIF
	'bouton_radio_publication_immediate' => 'Mi na ɖé wɛn xlɛ azɔn ɖokpo, sisɛɖo kpoɖo ɖiɖèxlɛ alɔdo, gânl lɛ̂ hɛn ɔ yé siwu sunsun yé ',

	// F
	'form_pet_message_commentaire' => 'wɛn, tɛ xójí?',
	'forum' => 'Kplékplé ',
	'forum_acces_refuse' => 'Mì sɔ síwú byɔ Kpékpé ɔ mɛ á.',
	'forum_attention_dix_caracteres' => 'vlɛ ! wékwín é wlán wɛn mí tɔn é sù wó á.', # MODIF
	'forum_attention_trois_caracteres' => 'vlɛ ! wékwín é wlán xóta mí tɔn é kpé àtɔn á.', # MODIF
	'forum_avez_selectionne' => 'mì cían:',
	'forum_cliquer_retour' => 'Mì zín @lɛkɔkplékplé@ mì yì',
	'forum_forum' => 'kpléklpé',
	'forum_info_modere' => 'Kpléklpé é lɔ ɖó jlɛɖɔtɔ, nú yé sɔ kɛn nú xògbè mì tɔn fó ɔ, é ná tɔn tà .', # MODIF
	'forum_lien_hyper' => 'cácádó', # MODIF
	'forum_message_definitif' => 'wɛn gùɖógùɖó tɔn, sɛɖó gblogblo ɔ jí',
	'forum_message_trop_long' => 'wɛn mì tɔn ɖìga ɖín. kpìnkpɛn tɔn ɖó ná zɛ wěkwin càkìkò wú á ', # MODIF
	'forum_ne_repondez_pas' => 'mì mà yígbè nú e-mailù é lɔ ó, àmɔ ɖò kplékplé ɔ mɛ ɔ mì kpɔn nɔtɛn é lɔ ', # MODIF
	'forum_page_url' => '(nú é nyí  ɖɔ wɛn mì tɔn tɛɖó wékpá é xlɛ ɖò àtɛ ɔ jí ɔ, kàbí wěmá é nɔ xlɛ xó gege ɔ, mì sìwú ɖè xótá àló nɔtɛn wěkpá tɔn ɖò fí.)',
	'forum_poste_par' => '@nyɔwlántɔ ɖókpóɖókpó sɛ wɛn ɖó@gbètákɛnxòkplé ɔ gbàfɔ, yè sìwú wlí wɛn mì tɔn hɛn á', # MODIF
	'forum_qui_etes_vous' => 'mɛcé ká ɖyè', # MODIF
	'forum_texte' => 'xó é ɖò wɛn ɔ mɛ ɔ :', # MODIF
	'forum_titre' => 'xótá :', # MODIF
	'forum_url' => 'URLU:', # MODIF
	'forum_valider' => 'sɔ kɛŋ ná  nù è mì cyán é',
	'forum_voir_avant' => 'mí kpɔn wɛn é lɔ có bó sɛɖó', # MODIF
	'forum_votre_email' => 'e-mailù mi tɔn  :', # MODIF
	'forum_votre_nom' => 'nyìkɔ mi tɔn :', # MODIF
	'forum_vous_enregistrer' => 'nú mi ná ɖó byɔ kplékplé é lɔ mɛ ɔ, mi ɖó ná ná nyìkɔ tɔn hwɛ. Mi zé sùnyíkɔ mi tɔn zé xlɛ. Nú mi mà kò nyìkɔ á, mi ɖó ná',
	'forum_vous_inscrire' => 'mi ɖó ná ná nyìkɔ .',

	// I
	'icone_poster_message' => 'sɛ wɛn dó',
	'icone_suivi_forum' => 'nɔkɔn xwíxwlété àgùn ɔ tɔn ',
	'icone_suivi_forums' => 'cɔ/tìtò klpékplé ɔ tɔn ',
	'icone_supprimer_message' => 'gbìɖí wɛn é lɔ',
	'icone_valider_message' => 'sɔ kɛn nú wɛn é lɔ',
	'info_activer_forum_public' => 'nú mi ná zɔn bɔ axì ná jɛ ɖò àgun ɔ mɛ ɔ ', # MODIF
	'info_appliquer_choix_moderation' => 'mi zán wàlɔ é lɔ ɖɛɖɛ:',
	'info_desactiver_forum_public' => 'kplékplénɔ lɛ ní jó xó dó',
	'info_envoi_forum' => 'mi sɛ wɛn àgún mɛ tɔn lɛ ɖó nyɔnwlántɔ lɛ ',
	'info_fonctionnement_forum' => 'Kplékplé ɔ sín yíyí:',
	'info_gauche_suivi_forum_2' => 'wémà é lɔ Tìtòtɔ lɛ kɛɖɛ wɛ síwú dàlɔmɛ', # MODIF
	'info_liens_syndiques_3' => 'kplékplé lɛ',
	'info_liens_syndiques_4' => 'Yé ɖò',
	'info_liens_syndiques_5' => 'kplékplé',
	'info_liens_syndiques_6' => 'E ɖò',
	'info_liens_syndiques_7' => 'yé bónú yé ní sɔ kɛn ná',
	'info_mode_fonctionnement_defaut_forum_public' => 'àzɔ yiyi wɛ',
	'info_option_email' => 'Mi yí gbè nú jònɔ é ná nyíkɔ lɛ ', # MODIF
	'info_pas_de_forum' => 'kplékplé mà tín',
	'item_activer_forum_administrateur' => 'tìtòtɔ lɛ sín kplékplé ní jɛ àzɔ wà jí',
	'item_desactiver_forum_administrateur' => 'Tìtótɔ lɛ',

	// L
	'lien_reponse_article' => 'yígbjè nú wékpá é lɔ',
	'lien_reponse_breve_2' => 'yígbjè nú xó kléwún é lɔ',
	'lien_reponse_rubrique' => 'yígbjè nú àkpáxwé  é lɔ',
	'lien_reponse_site_reference' => 'yígbjè nú gblogblojí ɔ  é lɔ :', # MODIF

	// O
	'onglet_messages_internes' => 'wɛn dódó',
	'onglet_messages_publics' => 'wɛn tò bí tùn ',
	'onglet_messages_vide' => 'wɛn mà ɖò wě',

	// R
	'repondre_message' => 'ɖò sin nu wɛn  é lɔ',

	// T
	'titre_cadre_forum_administrateur' => 'tìtòtɔ lɛ síŋ kplékplé',
	'titre_cadre_forum_interne' => 'kplékplé',
	'titre_forum' => 'kplékplé',
	'titre_forum_suivi' => 'Bɔ núkún nú kplékplé ɔ',
	'titre_page_forum_suivi' => 'Bɔnúkún kplékplé ɔ jí',
];
